#!/usr/bin/env python

#   FILE: pypvm.py -- A wrapper to provide additional functionality to the
#         pypvm module.  Import this instead of importing pypvm directly.
# AUTHOR: W. Michael Petullo, wp0002@drake.edu
#   DATE: 16 MAR 1998
#
# Copyright (c) 1999 W. Michael Petullo
# All rights reserved.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

from pypvm_core import *
from pickle import dumps, loads

#PvmDataDefault = 0
#PvmDataRaw     = 1
#PvmDataInPlace = 2

#PvmTaskDefault = 0
#PvmTaskHost    = 1
#PvmTaksArch    = 2
#PvmTaskDebug   = 4
#PvmTaskTrace   = 8
#PvmMppFront    = 16
#PvmHostCompl   = 32

#PvmTaskExit   = 1
#PvmHostDelete = 2
#PvmHostAdd    = 3

#PvmRoute          = 1
#PvmDebugMask      = 2
#PvmAutoErr        = 3
#PvmOutputTid      = 4
#PvmOutputCode     = 5
#PvmTraceTid       = 6
#PvmTraceCode      = 7
#PvmFragSize       = 8
#PvmResvTids       = 9
#PvmSelfOutputTid  = 10
#PvmSelfOutputCode = 11
#PvmSelfTraceTid   = 12
#PvmSelfTraceCode  = 13
#PvmShowTids       = 14
#PvmPollType       = 15
#PvmPollTime       = 16

# ============================ pk () ==========================================
def pk (obj):
#  PRE: obj is assigned a Python object
# POST: obj has been packed into PVM send buffer
	pkstr (dumps (obj))

# ============================ upk () =========================================
def upk ():
# POST: FCTVAL == a Python object read from PVM receive buffer
	return (loads (upkstr ()))



"""
 setup.py: This is a setup file for Python's Distutils
           installion system.

 Created: November 26, 2002 Sam Tannous
 Adapted: February 2007, Raik Gruenberg

 If you need help, run "python setup.py --help" and
 "python setup.py --help-commands"

 for windows 2k (with Cygwin gcc), you need
 "python setup.py build --compiler=mingw32"

 for all other UNIX building, simply "python setup.py build" will suffice


 this builds various packages

    python setup.py bdist                  tar.gz file
    python setup.py bdist_wininst          win 2k install wizard exe
    python setup.py bdist_dumb             a tar.gz file to be untarred from /
    python setup.py bdist_rpm              two RPMs for Linux

    python setup.py build                  builds everything for an install
    python setup.py install                install everything 
    
 and usually puts RPMS, tgz, exe files in a directory called dist.
 See the Python Distutils web pages for more information on installing
 and other options:
  
    http://www.python.org/doc/current/lib/module-distutils.html

 $Revision: 1.3 $
 $Source: /cvsroot/pypvm/pypvm/setup.py,v $

"""
import sys
import os
from distutils import sysconfig
from distutils.core import setup
from distutils.extension import Extension

prefix = sysconfig.PREFIX

try:
    pvmroot = os.environ['PVM_ROOT']
    pvmarch = os.environ['PVM_ARCH']
except:
    raise Exception, """$PVM_ROOT and/or $PVM_ARCH are not defined.
    You need to install pvm (including shared libraries) and set the PVM_ROOT
    and PVM_ARCH variables before building pypvm.
    See http://biskit.pasteur.fr/install/libraries
    """


inc_dirs = [prefix  + "/include",
            pvmroot + "/include"]

lib_dirs = [prefix  + "/lib",
            prefix  + "/lib64",
            pvmroot + "/lib/" + pvmarch,
            pvmroot + "/pvmgs/" + pvmarch]

libs = ["pvm3","pvmtrc","fpvm3","gpvm3"]

pypvm_extension = Extension(name="pypvm_core",
                            sources = ["pypvm_coremodule.c"],
                            include_dirs = inc_dirs,
                            libraries = libs,
                            library_dirs = lib_dirs)

setup(name="pypvm",
      version="0.95x",
      description="Python Wrapper for PVM",
      author="W. Michael Petullo and Greg Baker",
      author_email="pypvm-discuss@lists.sourceforge.net",
      url="http://pypvm.sourceforge.net/",
      py_modules = ['pypvm'],
      ext_modules = [pypvm_extension]
      )
    

